SetSnapshotReferenceUpdate class
- Inheritance
-
- Object
- TableUpdate
- SetSnapshotReferenceUpdate
Constructors
- SetSnapshotReferenceUpdate({required String referenceName, required SnapshotReference reference})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- reference → SnapshotReference
-
final
- referenceName → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited