VectorList class

Annotations
  • @experimental

Constructors

VectorList({required List<VectorMatch> vectors, String? nextToken})
const
VectorList.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
nextToken String?
The token to pass as nextToken to fetch the next page, if any.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
vectors List<VectorMatch>
The vectors in this page.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited